package com.link.core.util;

import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Random;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class StringUtils {
   private static final Logger logger = LogManager.getLogger(StringUtils.class);
   private static final String ILLEGAL_SEARCHCAHRACTERS = "请勿输入下列字符\r'，--，#，/*，*/，;，+，|，$，%，\"，\\,)";
   private static final Pattern ILLEGAL_SEARCH_PATTERN = Pattern.compile("\\'|--|#|/\\*|\\*/|\\+|;|\\||(&lt;)|(&gt;)|\\$|\\%|\"|\\\\|\\)|(%27)|(%23)|(%2f\\*)|(\\*%2f)|(%2B)|(%3B)", 2);
   private static final Pattern ESCAPE_STRING_PATTERN = Pattern.compile("\\'|\\\\", 2);
   private static final Pattern ESCAPE_STRING_PATTERN_LIKE = Pattern.compile("\\'|\\%|\\\\|_", 2);
   private static final Pattern TOCALMEL_CASE_PATTERN = Pattern.compile("_\\w");
   private static final Pattern TOHUNGARIAN_CASE_PATTERN = Pattern.compile("[A-Z]");
   private static final Pattern EMOJI_PATTERN = Pattern.compile("[\ud83c\udc00-\ud83c\udfff]|[\ud83d\udc00-\ud83d\udfff]|[☀-⟿]", 66);
   public static final String DELIM_DEFAULT = ".";

   public static boolean haveIllegalSearchCharacters(String param) {
      boolean flag = false;

      for(Matcher match = ILLEGAL_SEARCH_PATTERN.matcher(param); match.find(); flag = true) {
      }

      return flag;
   }

   public static String changeIllegalSearchCharacters(String param) {
      String result = param.replaceAll("\\'|--|#|/\\*|\\*/|\\+|;|\\||&|\\$|\\%|\"|\\\\|\\)|(%27)|(%23)|(%2f\\*)|(\\*%2f)|(%2B)|(%3B)", "");
      return result;
   }

   public static String getIllegalSearchCharactersInfo() {
      return "请勿输入下列字符\r'，--，#，/*，*/，;，+，|，$，%，\"，\\,)";
   }

   public static String[] convertStrToArray(String str) {
      StringTokenizer st = new StringTokenizer(str, ",");
      String[] strArray = new String[st.countTokens()];

      for(int i = 0; st.hasMoreTokens(); strArray[i++] = st.nextToken()) {
      }

      return strArray;
   }

   public static String escapeString(String str, String operator) {
      if (isBlank(operator)) {
         return "filter_operator_is_invalid";
      } else {
         Matcher match;
         if (!operator.equalsIgnoreCase("LIKE") && !operator.equalsIgnoreCase("OR LIKE")) {
            match = ESCAPE_STRING_PATTERN.matcher(str);
         } else {
            str = str.replace("\\", "\\\\");
            match = ESCAPE_STRING_PATTERN_LIKE.matcher(str);
         }

         Map<String, String> targetMap = new HashMap();

         String target;
         while(match.find()) {
            target = match.group();
            targetMap.put(target, (Object)null);
         }

         Set<String> keySet = targetMap.keySet();

         for(Iterator<String> iter = keySet.iterator(); iter.hasNext(); str = str.replace(target, "\\" + target)) {
            target = (String)iter.next();
         }

         return str;
      }
   }

   public static String getStr(String[] arry, String symbol) {
      String str = "";
      if (arry.length > 0) {
         for(int i = 0; i < arry.length - 1; ++i) {
            str = str + arry[i] + symbol;
         }
      }

      str = str + arry[arry.length - 1];
      return str;
   }

   public static String urlEncoder(String str, String enc) throws UnsupportedEncodingException {
      if (enc == null || enc.length() <= 0) {
         enc = "UTF-8";
      }

      String keyWord = URLEncoder.encode(str, enc);
      return keyWord;
   }

   public static boolean isNull(String str) {
      return null == str || "".equals(str);
   }

   public static String null2EmptyString(String str) {
      try {
         return null != str && str.length() > 0 && !"null".equals(str) ? str : "";
      } catch (Exception var2) {
         return "";
      }
   }

   public static boolean isNum(String str) {
      return str.matches("^[-+]?(([0-9]+)([.]([0-9]+))?|([.]([0-9]+))?)$");
   }

   private StringUtils() {
   }

   public static String toString(Object obj) {
      StringBuffer buffer = new StringBuffer();
      if (obj != null) {
         buffer.append(obj);
      }

      return buffer.toString();
   }

   public static boolean isBlank(String str) {
      return str == null || "".equals(str.trim()) || str == "null";
   }

   public static boolean isNotBlank(String str) {
      return !isBlank(str);
   }

   public static String getPrefix(String str) {
      return getPrefix(str, ".");
   }

   public static String getPrefix(String str, String delim) {
      String prefix = "";
      if (isNotBlank(str) && isNotBlank(delim)) {
         int pos = str.indexOf(delim);
         if (pos > 0) {
            prefix = str.substring(0, pos);
         }
      }

      return prefix;
   }

   public static String getSuffix(String str) {
      return getSuffix(str, ".");
   }

   public static String getSuffix(String str, String delim) {
      String suffix = "";
      if (isNotBlank(str) && isNotBlank(delim)) {
         int pos = str.lastIndexOf(delim);
         if (pos > 0) {
            suffix = str.substring(pos + 1);
         }
      }

      return suffix;
   }

   public static String newString(String str, int repeatCount) {
      StringBuffer buf = new StringBuffer();

      for(int i = 0; i < repeatCount; ++i) {
         buf.append(str);
      }

      return buf.toString();
   }

   public static String hideChars(String str, int index, int length) {
      return hideChars(str, index, length, true);
   }

   public static String hideChars(String str, int start, int end, boolean confusion) {
      StringBuffer buf = new StringBuffer();
      if (isNotBlank(str)) {
         int startIndex = Math.min(start, end);
         int endIndex = Math.max(start, end);
         if (startIndex < 0 || startIndex > str.length()) {
            startIndex = 0;
         }

         if (endIndex < 0 || endIndex > str.length()) {
            endIndex = str.length();
         }

         String temp = newString("*", confusion ? 4 : endIndex - startIndex);
         buf.append(str).replace(startIndex, endIndex, temp);
      }

      return buf.toString();
   }

   public static String toLowerCase(String str) {
      StringBuffer buffer = new StringBuffer(str);

      for(int i = 0; i < buffer.length(); ++i) {
         char temp = buffer.charAt(i);
         buffer.setCharAt(i, Character.toLowerCase(temp));
      }

      return buffer.toString();
   }

   public static String toUpperCase(String str) {
      StringBuffer buffer = new StringBuffer(str);

      for(int i = 0; i < buffer.length(); ++i) {
         char temp = buffer.charAt(i);
         buffer.setCharAt(i, Character.toUpperCase(temp));
      }

      return buffer.toString();
   }

   public static String firstStringToUpperCase(String str) {
      return isNull(str) ? str : str.substring(0, 1).toUpperCase() + str.substring(1);
   }

   public static String substringAfterLast(String str, String separator) {
      if (isNull(str)) {
         return str;
      } else if (isNull(separator)) {
         return "";
      } else {
         int pos = str.lastIndexOf(separator);
         return pos != -1 && pos != str.length() - separator.length() ? str.substring(pos + separator.length()) : "";
      }
   }

   public static String toCalmelCase(String str) {
      StringBuffer buffer = new StringBuffer(str);
      if (buffer.length() > 0) {
         char tempChar = buffer.charAt(0);
         buffer.setCharAt(0, Character.toLowerCase(tempChar));
         Matcher matcher = TOCALMEL_CASE_PATTERN.matcher(buffer.toString());

         while(matcher.find()) {
            String temp = matcher.group();
            int index = buffer.indexOf(temp);
            buffer.replace(index, index + temp.length(), temp.replace("_", "").toUpperCase());
         }
      }

      return buffer.toString();
   }

   public static String toHungarianCase(String str) {
      StringBuffer buffer = new StringBuffer(str);
      if (buffer.length() > 0) {
         Matcher matcher = TOHUNGARIAN_CASE_PATTERN.matcher(buffer.toString());

         while(matcher.find()) {
            String temp = matcher.group();
            int index = buffer.indexOf(temp);
            buffer.replace(index, index + temp.length(), (index > 0 ? "_" : "") + temp.toLowerCase());
         }
      }

      return buffer.toString();
   }

   public static String firstCharUpperCase(String str) {
      StringBuffer buffer = new StringBuffer(str);
      if (buffer.length() > 0) {
         char temp = buffer.charAt(0);
         buffer.setCharAt(0, Character.toUpperCase(temp));
      }

      return buffer.toString();
   }

   public static String firstCharLowerCase(String str) {
      StringBuffer buffer = new StringBuffer(str);
      if (buffer.length() > 0) {
         char temp = buffer.charAt(0);
         buffer.setCharAt(0, Character.toLowerCase(temp));
      }

      return buffer.toString();
   }

   public static String array2String(Object[] objs) {
      StringBuffer buffer = new StringBuffer();
      if (objs != null) {
         for(int i = 0; i < objs.length; ++i) {
            buffer.append(objs[i]).append(",");
         }
      }

      buffer.deleteCharAt(buffer.length() - 1);
      return buffer.toString();
   }

   public static boolean equals(String str1, String str2) {
      return str1 != null && str2 != null ? str1.equals(str2) : false;
   }

   public static String bytes2Hex(byte[] bts) {
      String des = "";
      String tmp = null;

      for(int i = 0; i < bts.length; ++i) {
         tmp = Integer.toHexString(bts[i] & 255);
         if (tmp.length() == 1) {
            des = des + "0";
         }

         des = des + tmp;
      }

      return des;
   }

   public static String replaceNullString(String str) {
      return str == null ? "" : str;
   }

   public static int strRepetitions(String str, String oriStr) {
      int count = 0;

      for(String tmp = str; tmp != null && tmp.length() >= oriStr.length(); tmp = tmp.substring(1)) {
         if (tmp.indexOf(oriStr) == 0) {
            ++count;
         }
      }

      return count;
   }

   public static String filterEmoji(String source) {
      if (source != null) {
         Matcher emojiMatcher = EMOJI_PATTERN.matcher(source);
         if (emojiMatcher.find()) {
            source = emojiMatcher.replaceAll("*");
            source = filterEmoji2(source);
            return source;
         } else {
            source = filterEmoji2(source);
            return source;
         }
      } else {
         return source;
      }
   }

   public static String filterEmoji2(String source) {
      if (source.contains("*")) {
      }

      if (isBlank(source)) {
         return source;
      } else {
         StringBuilder buf = null;
         int len = source.length();

         for(int i = 0; i < len; ++i) {
            char codePoint = source.charAt(i);
            if (isNotEmojiCharacter(codePoint)) {
               if (buf == null) {
                  buf = new StringBuilder(source.length());
               }

               buf.append(codePoint);
            }
         }

         if (buf == null) {
            return source;
         } else if (buf.length() == len) {
            buf = null;
            return source;
         } else {
            return buf.toString();
         }
      }
   }

   private static boolean isNotEmojiCharacter(char codePoint) {
      return codePoint == 0 || codePoint == '\t' || codePoint == '\n' || codePoint == '\r' || codePoint >= ' ' && codePoint <= '\ud7ff' || codePoint >= '\ue000' && codePoint <= '�' || codePoint >= 65536 && codePoint <= 1114111;
   }

   public static String getRandomCharAndNumr(Integer length) {
      String str = "";
      Random random = new Random();

      for(int i = 0; i < length; ++i) {
         boolean flag = random.nextBoolean();
         if (flag) {
            str = str + (char)(65 + random.nextInt(26));
         } else {
            str = str + String.valueOf(random.nextInt(10));
         }
      }

      return str;
   }

   public static boolean equalsIgnoreCase(String str1, String str2) {
      return str1 != null && str2 != null ? str1.equalsIgnoreCase(str2) : false;
   }

   public static boolean checkTable(String param, int length) {
      if (null == param) {
         return false;
      } else {
         return param.length() <= length;
      }
   }

   public static boolean isChineseChar(char c) throws UnsupportedEncodingException {
      return String.valueOf(c).getBytes("UTF-8").length > 1;
   }

   public static String substring(String orignal, int count) throws UnsupportedEncodingException {
      if (orignal != null && !"".equals(orignal)) {
         orignal = new String(orignal.getBytes(), StandardCharsets.UTF_8);
         if (count > 0 && count < orignal.getBytes(StandardCharsets.UTF_8).length) {
            StringBuffer buff = new StringBuffer();

            for(int i = 0; i < count; ++i) {
               char c = orignal.charAt(i);
               buff.append(c);
               if (isChineseChar(c)) {
                  --count;
               }
            }

            return new String(buff.toString().getBytes(), StandardCharsets.UTF_8);
         }
      }

      return orignal;
   }

   public static String gsubstring(String orignal, int count) throws UnsupportedEncodingException {
      if (orignal != null && !"".equals(orignal)) {
         orignal = new String(orignal.getBytes(), "GBK");
         if (count > 0 && count < orignal.getBytes("GBK").length) {
            StringBuffer buff = new StringBuffer();

            for(int i = 0; i < count; ++i) {
               char c = orignal.charAt(i);
               buff.append(c);
               if (isChineseChar(c)) {
                  --count;
               }
            }

            return buff.toString();
         }
      }

      return orignal;
   }

   public static String idgui(String s, int num) {
      int changdu = s.getBytes().length;
      if (changdu > num) {
         s = s.substring(0, s.length() - 1);
         s = idgui(s, num);
      }

      return s;
   }

   public static void main(String[] args) {
      String str = "log.text.txt";
      String param = "123";
      String str1 = "as'd";
      String str2 = "sldfj\\\\owejf";
      String str3 = "'";
      String str4 = "'123'";
      String str5 = "'12%3'";
      String str6 = "12_3";
      String str7 = "12\\3";
      System.out.println(escapeString(str1, "LIKE"));
      System.out.println(escapeString(str2, "LIKE"));
      System.out.println(escapeString(str3, "LIKE"));
      System.out.println(escapeString(str4, "LIKE"));
      System.out.println(escapeString(str5, "LIKE"));
      System.out.println(escapeString(str6, "LIKE"));
      System.out.println(escapeString(str7, "LIKE"));
      System.out.println("===================");
      System.out.println(escapeString(str1, "="));
      System.out.println(escapeString(str2, "="));
      System.out.println(escapeString(str3, "="));
      System.out.println(escapeString(str4, "="));
      System.out.println(escapeString(str5, "="));
      System.out.println(escapeString(str6, "="));
      System.out.println(escapeString(str7, "="));
   }

   public static boolean isStr(String s) {
      String zeroStr = BigDecimal.ZERO.toString();
      if (zeroStr.equals(s)) {
         return false;
      } else {
         char[] charArray = s.toCharArray();
         char[] var3 = charArray;
         int var4 = charArray.length;

         for(int var5 = 0; var5 < var4; ++var5) {
            char c = var3[var5];
            if (!Character.isDigit(c)) {
               return true;
            }
         }

         return s.startsWith(zeroStr) || s.length() > 11;
      }
   }
}
